// Copyright 2016-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
//
// Licensed under the Apache License, Version 2.0 (the "License"). You may
// not use this file except in compliance with the License. A copy of the
// License is located at
//
//     http://aws.amazon.com/apache2.0/
//
// or in the "license" file accompanying this file. This file is distributed
// on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
// express or implied. See the License for the specific language governing
// permissions and limitations under the License.

package operations

// This file was generated by the swagger tool.
// Editing this file might prove futile when you re-run the swagger generate command

import (
	"net/http"
	"time"

	"golang.org/x/net/context"

	"github.com/go-openapi/errors"
	"github.com/go-openapi/runtime"
	cr "github.com/go-openapi/runtime/client"

	strfmt "github.com/go-openapi/strfmt"
)

// NewListDeploymentsParams creates a new ListDeploymentsParams object
// with the default values initialized.
func NewListDeploymentsParams() *ListDeploymentsParams {
	var ()
	return &ListDeploymentsParams{

		timeout: cr.DefaultTimeout,
	}
}

// NewListDeploymentsParamsWithTimeout creates a new ListDeploymentsParams object
// with the default values initialized, and the ability to set a timeout on a request
func NewListDeploymentsParamsWithTimeout(timeout time.Duration) *ListDeploymentsParams {
	var ()
	return &ListDeploymentsParams{

		timeout: timeout,
	}
}

// NewListDeploymentsParamsWithContext creates a new ListDeploymentsParams object
// with the default values initialized, and the ability to set a context for a request
func NewListDeploymentsParamsWithContext(ctx context.Context) *ListDeploymentsParams {
	var ()
	return &ListDeploymentsParams{

		Context: ctx,
	}
}

// NewListDeploymentsParamsWithHTTPClient creates a new ListDeploymentsParams object
// with the default values initialized, and the ability to set a custom HTTPClient for a request
func NewListDeploymentsParamsWithHTTPClient(client *http.Client) *ListDeploymentsParams {
	var ()
	return &ListDeploymentsParams{
		HTTPClient: client,
	}
}

/*ListDeploymentsParams contains all the parameters to send to the API endpoint
for the list deployments operation typically these are written to a http.Request
*/
type ListDeploymentsParams struct {

	/*DeploymentToken
	  Deployment token

	*/
	DeploymentToken string
	/*Name
	  Name of environment

	*/
	Name string
	/*NextToken
	  Pagination token

	*/
	NextToken *string

	timeout    time.Duration
	Context    context.Context
	HTTPClient *http.Client
}

// WithTimeout adds the timeout to the list deployments params
func (o *ListDeploymentsParams) WithTimeout(timeout time.Duration) *ListDeploymentsParams {
	o.SetTimeout(timeout)
	return o
}

// SetTimeout adds the timeout to the list deployments params
func (o *ListDeploymentsParams) SetTimeout(timeout time.Duration) {
	o.timeout = timeout
}

// WithContext adds the context to the list deployments params
func (o *ListDeploymentsParams) WithContext(ctx context.Context) *ListDeploymentsParams {
	o.SetContext(ctx)
	return o
}

// SetContext adds the context to the list deployments params
func (o *ListDeploymentsParams) SetContext(ctx context.Context) {
	o.Context = ctx
}

// WithHTTPClient adds the HTTPClient to the list deployments params
func (o *ListDeploymentsParams) WithHTTPClient(client *http.Client) *ListDeploymentsParams {
	o.SetHTTPClient(client)
	return o
}

// SetHTTPClient adds the HTTPClient to the list deployments params
func (o *ListDeploymentsParams) SetHTTPClient(client *http.Client) {
	o.HTTPClient = client
}

// WithDeploymentToken adds the deploymentToken to the list deployments params
func (o *ListDeploymentsParams) WithDeploymentToken(deploymentToken string) *ListDeploymentsParams {
	o.SetDeploymentToken(deploymentToken)
	return o
}

// SetDeploymentToken adds the deploymentToken to the list deployments params
func (o *ListDeploymentsParams) SetDeploymentToken(deploymentToken string) {
	o.DeploymentToken = deploymentToken
}

// WithName adds the name to the list deployments params
func (o *ListDeploymentsParams) WithName(name string) *ListDeploymentsParams {
	o.SetName(name)
	return o
}

// SetName adds the name to the list deployments params
func (o *ListDeploymentsParams) SetName(name string) {
	o.Name = name
}

// WithNextToken adds the nextToken to the list deployments params
func (o *ListDeploymentsParams) WithNextToken(nextToken *string) *ListDeploymentsParams {
	o.SetNextToken(nextToken)
	return o
}

// SetNextToken adds the nextToken to the list deployments params
func (o *ListDeploymentsParams) SetNextToken(nextToken *string) {
	o.NextToken = nextToken
}

// WriteToRequest writes these params to a swagger request
func (o *ListDeploymentsParams) WriteToRequest(r runtime.ClientRequest, reg strfmt.Registry) error {

	r.SetTimeout(o.timeout)
	var res []error

	// query param deploymentToken
	qrDeploymentToken := o.DeploymentToken
	qDeploymentToken := qrDeploymentToken
	if qDeploymentToken != "" {
		if err := r.SetQueryParam("deploymentToken", qDeploymentToken); err != nil {
			return err
		}
	}

	// path param name
	if err := r.SetPathParam("name", o.Name); err != nil {
		return err
	}

	if o.NextToken != nil {

		// query param nextToken
		var qrNextToken string
		if o.NextToken != nil {
			qrNextToken = *o.NextToken
		}
		qNextToken := qrNextToken
		if qNextToken != "" {
			if err := r.SetQueryParam("nextToken", qNextToken); err != nil {
				return err
			}
		}

	}

	if len(res) > 0 {
		return errors.CompositeValidationError(res...)
	}
	return nil
}
